%latent_heat
% Plots the temperature of a substace /deg Celcius vs heat absorbed (kJ) per kg.
%
% LAST UPDATED by Andy French 4/10/2015

function latent_heat

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% INPUTS %%

%Define list of substances
substances = {
    'Water',...
    'Ammonia',...
    'Nitrogen',...
    'Ethyl alcohol'
    };

%Set number of data points
N = 1000;

%Set fontsize
fsize = 18;

%Set temperature /deg C and specific heat ranges /kJ per kg
Qmin = 0;
Qmax = 2500;
Tmin = -250;
Tmax = 150;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Initialize heat Q and Temperature T matrices to enable graphs to be
%plotted
Q = linspace(Qmin,Qmax,N);
dQ = 1e3*(Qmax-Qmin)/(N-1);  %In Joules per kg
Q = repmat(Q.',[1,length(substances)]);
T = Tmin*ones(N,length(substances));

%Step through substances and generate Temperature vs heat per kg graphs
for n=1:length(substances)
    
    %Obtain thermal parameters for chosen substance
    [T_melt,L_fusion, T_boil, L_vap, c_solid, c_liq, c_gas] =...
        choose_substance(substances{n});
    
    %Initialize temperature, and add heat step by step
    TT=Tmin;
    for k=2:N
        if TT<T_melt
            %Solid phase
            TT = TT + dQ/c_solid ;
        elseif (TT>=T_melt) && (TT<T_boil) && (L_fusion > 0)
            %Melting phase
             L_fusion = L_fusion - dQ;        
           elseif (TT>=T_melt) && (TT<T_boil) && (L_fusion <= 0)
            %Liquid phase
            TT = TT + dQ/c_liq ;
        elseif (TT>=T_boil) && (L_vap > 0)
            %Boiling phase
            L_vap = L_vap - dQ ;
        else
            %Gas phase
            TT = TT + dQ/c_gas ;
        end
        T(k,n) = TT;        
    end
end

%Plot and print graphs
figure('name','latent heat','color',[1 1 1] );
plot(Q,T);
xlim([Qmin,Qmax])
ylim([Tmin,Tmax]);
grid on;
xlabel( 'Heat added / kJ per kg', 'fontsize', fsize );
ylabel( 'Temperature / ^oC', 'fontsize', fsize );
title( 'Temperature vs heat per kg added', 'fontsize', fsize );
set(gca,'fontsize', fsize );
legend(substances,'fontsize',fsize,'location','eastoutside')
print( gcf,'latent heat graphs','-dpng','-r300' );
close(gcf);

%%

%Melting temperature /degC, Specific latent heat of fusion /Jkg^-1, Boiling
%Point /degC, Specific latent heat of vaporization /Jkg^-1
%Isobaric (i.e constant pressure) specfic heat capacity in solid, liquid or
%gas phase /Jkg^-1K-1
% Data from:
% http://www.kayelaby.npl.co.uk/
% http://ipodphysics.com/thermal-latent-heat.php
% https://en.wikipedia.org/wiki/Heat_capacity
% http://physics.info/heat-sensible/
function [T_melt,L_fusion, T_boil, L_vap, c_solid, c_liq, c_gas] = choose_substance(s)

if strcmp( s, 'Ammonia' )
    T_melt = -77.8;
    L_fusion = 33.3e4;
    T_boil = -33.4;
    L_vap = 13.7e5;
    c_solid = 3*8.314/17.031e-3 ;  %Dulong & Petit, NH3 is 17.031e-3 kg per mol;
    c_liq = 4700;
    c_gas = 2060;
elseif strcmp( s, 'Benzene' )
    T_melt = 5.5;
    L_fusion = 12.6e4;
    T_boil = 80.1;
    L_vap = 3.94e5;
    c_solid = 118.4/78.11e-3 ;  %78.11e-2 kg per mol
    c_liq = 2100 ;
    c_gas = 1090;
elseif strcmp( s, 'Copper' )
    T_melt = 1083;
    L_fusion = 20.7e4;
    T_boil = 2566;
    L_vap = 47.3e5;
    c_solid = 385 ;
    c_liq = 386;
    c_gas = 380;
elseif strcmp( s, 'Ethyl alcohol' )
    T_melt = -114.4;
    L_fusion = 10.8e4;
    T_boil = 78.3;
    L_vap = 8.55e5;
    c_solid = 970 ;
    c_liq = 2440;
    c_gas = 1900;
elseif strcmp( s, 'Gold' )
    T_melt = 1063;
    L_fusion = 6.28e4;
    T_boil = 2808;
    L_vap = 17.2e5;
    c_solid = 25.4/ 197e-3 ;  %197e-3 kg per mol
    c_liq = NaN ;
    c_gas = NaN;
elseif strcmp( s, 'Lead' )
    T_melt = 327.3;
    L_fusion = 2.32e4;
    T_boil = 1750;
    L_vap = 8.59e5;
    c_solid = 136;
    c_liq = 117.6;
    c_gas = NaN ;
elseif strcmp( s, 'Mercury' )
    T_melt = -38.9;
    L_fusion = 1.14;
    T_boil = 356.6;
    L_vap = 2.96e5;
    c_solid = 3*8.314/200.59e-3 ;  %Dulong & Petit, Hg is 200.59e-3 kg per mol;
    c_liq = 140;
    c_gas = NaN;
elseif strcmp( s, 'Nitrogen' )
    T_melt = -210.0;
    L_fusion = 2.57e4;
    T_boil = -195.8;
    L_vap = 2.00e5;
    c_solid = 3*8.314/28.0134e-3 ;  %Dulong & Petit, N2 is 28.0134e-3 kg per mol
    c_liq = 2042;
    c_gas = 1040;
elseif strcmp( s, 'Oxygen' )
    T_melt = -218.8;
    L_fusion = 1.39e4;
    T_boil = -183.0;
    L_vap = 2.13e5;
    c_solid = 3*8.314/32.00e-3 ;  %Dulong & Petit, O2 is 32.000e-3 kg per mol ;
    c_liq = 1669;
    c_gas = 919;
elseif strcmp( s, 'Water' )
    T_melt = 0;
    L_fusion = 33.5e4;
    T_boil = 100;
    L_vap = 22.6e5;
    c_solid = 2090 ;
    c_liq = 4186 ;
    c_gas = 1930;
else
    %Default is Water
    T_melt = 0;
    L_fusion = 33.5e4;
    T_boil = 100;
    L_vap = 22.6e5;
    c_solid = 2090 ;
    c_liq = 4186 ;
    c_gas = 1930;
end

%End of code
